<?php
/**
 * @package Azura Joomla Pagebuilder
 * @author Cththemes - www.cththemes.com
 * @date: 15-07-2014
 *
 * @copyright  Copyright ( C ) 2014 cththemes.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */
defined('_JEXEC') or die;

use Joomla\Registry\Registry;
use Joomla\String\StringHelper;

class AzuraPagebuilderTablePage extends JTable
{
	/**
	 * Constructor
	 *
	 * @param   JDatabaseDriver  &$db  A database connector object
	 */
	public function __construct(&$db)
	{
		parent::__construct('#__azurapagebuilder_pages', 'id', $db);
		JTableObserverTags::createObserver($this, array('typeAlias' => 'com_azurapagebuilder.page'));
		JTableObserverContenthistory::createObserver($this, array('typeAlias' => 'com_azurapagebuilder.page'));

		// Set the alias since the column is called state
		$this->setColumnAlias('published', 'state');
	}


	public function bind($array, $ignore = '')
	{

		// Search for the {readmore} tag and split the text up accordingly.
		if (isset($array['shortcode']))
		{
			$pattern = '#<hr\s+id=("|\')system-readmore("|\')\s*\/*>#i';
			$tagPos = preg_match($pattern, $array['shortcode']);
			// echo'<pre>';var_dump($array['shortcode']);
			// echo'<pre>';var_dump($tagPos);
			if ($tagPos === 0)
			{
				//$array['introtext'] = '';
				$array['fulltext'] = '';
			}
			else
			{
				list ($array['introtext'], $array['shortcode']) = preg_split($pattern, $array['shortcode'], 2);
				$array['fulltext'] = '';
			}
		}

		if (isset($array['params']) && is_array($array['params']))
		{
			$registry = new JRegistry;
			$registry->loadArray($array['params']);
			$array['params'] = (string) $registry;
		}

		if (isset($array['metadata']) && is_array($array['metadata']))
		{
			$registry = new JRegistry;
			$registry->loadArray($array['metadata']);
			$array['metadata'] = (string) $registry;
		}


		// Bind the rules.
		if (isset($array['rules']) && is_array($array['rules']))
		{
			//echo '<pre>';var_dump($array['rules']);die;
			$rules = new JAccessRules($array['rules']);
			$this->setRules($rules);
		}

		//$ignore = array('introtext');
		//var_dump($array['description']);die;
		return parent::bind($array, $ignore);
	}

	/**
	 * Method to compute the default name of the asset.
	 * The default name is in the form `table_name.id`
	 * where id is the value of the primary key of the table.
	 *
	 * @return	string
	 * @since	2.5
	 */
	protected function _getAssetName()
	{
		$k = $this->_tbl_key;
		return 'com_azurapagebuilder.page.'.(int) $this->$k;
	}
	/**
	 * Method to return the title to use for the asset table.
	 *
	 * @return	string
	 * @since	2.5
	 */
	protected function _getAssetTitle()
	{
		return $this->title;
	}

	/**
	 * Method to get the asset-parent-id of the item
	 *
	 * @return	int
	 */
	protected function _getAssetParentId(JTable $table = NULL, $id = NULL)
	{
		// We will retrieve the parent-asset from the Asset-table
		$assetParent = JTable::getInstance('Asset');
		// Default: if no asset-parent can be found we take the global asset
		$assetParentId = $assetParent->getRootId();

		// Find the parent-asset
		if (($this->catid)&& !empty($this->catid))
		{
			// The item has a category as asset-parent
			$assetParent->loadByName('com_azurapagebuilder.category.' . (int) $this->catid);
		}
		else
		{
			// The item has the component as asset-parent
			$assetParent->loadByName('com_azurapagebuilder');
		}

		// Return the found asset-parent-id
		if ($assetParent->id)
		{
			$assetParentId=$assetParent->id;
		}
		
		return $assetParentId;
	}


	public function store($updateNulls = false)
	{
		$date	= JFactory::getDate();
		$user	= JFactory::getUser();

		if ($this->id)
		{
			// Existing item
			$this->modified		= $date->toSql();
			$this->modified_by	= $user->get('id');
		}
		else
		{
			// New product. A product created and created_by field can be set by the user,
			// so we don't touch either of these if they are set.
			if (!(int) $this->created)
			{
				$this->created = $date->toSql();
			}
			if (empty($this->created_by))
			{
				$this->created_by = $user->get('id');
			}
		}

		// Set publish_up to null date if not set
		if (!$this->publish_up)
		{
			$this->publish_up = $this->_db->getNullDate();
		}

		// Set publish_down to null date if not set
		if (!$this->publish_down)
		{
			$this->publish_down = $this->_db->getNullDate();
		}

		// Verify that the alias is unique
		$table = JTable::getInstance('Page', 'AzuraPagebuilderTable');



		if ($table->load(array('alias' => $this->alias)) && ($table->id != $this->id || $this->id == 0))
		{
			$this->setError(JText::_('COM_AZURAPAGEBUILDER_ERROR_UNIQUE_ALIAS'));
			return false;
		}

		// Convert IDN urls to punycode
		//$this->url = JStringPunycode::urlToPunycode($this->url);

		return parent::store($updateNulls);
	}

	/**
	 * Overloaded check method to ensure data integrity.
	 *
	 * @return  boolean  True on success.
	 */
	public function check()
	{
	

		// check for valid name
		if (trim($this->title) == '')
		{
			$this->setError(JText::_('COM_AZURAPAGEBUILDER_WARNING_PROVIDE_VALID_NAME'));
			return false;
		}

		// check for existing name
		// $query = 'SELECT id FROM #__azurapagebuilder_pages WHERE title = '.$this->_db->quote($this->title);
		// $this->_db->setQuery($query);

		// $xid = (int) $this->_db->loadResult();
		// if ($xid && $xid != (int) $this->id)
		// {
		// 	$this->setError(JText::_('COM_AZURAPAGEBUILDER_ERR_PRODUCT_TABLES_NAME'));
		// 	return false;
		// }

		if (empty($this->alias))
		{
			$this->alias = $this->title;
		}
		$this->alias = JApplication::stringURLSafe($this->alias);
		if (trim(str_replace('-', '', $this->alias)) == '')
		{
			$this->alias = JFactory::getDate()->format("Y-m-d-H-i-s");
		}

		// Check the publish down date is not earlier than publish up.
		if ($this->publish_down > $this->_db->getNullDate() && $this->publish_down < $this->publish_up)
		{
			$this->setError(JText::_('JGLOBAL_START_PUBLISH_AFTER_FINISH'));
			return false;
		}

		// clean up keywords -- eliminate extra spaces between phrases
		// and cr (\r) and lf (\n) characters from string
		if (!empty($this->metakey))
		{
			// only process if not empty
			$bad_characters = array("\n", "\r", "\"", "<", ">"); // array of characters to remove
			$after_clean = JString::str_ireplace($bad_characters, "", $this->metakey); // remove bad characters
			$keys = explode(',', $after_clean); // create array using commas as delimiter
			$clean_keys = array();

			foreach ($keys as $key)
			{
				if (trim($key)) {  // ignore blank keywords
					$clean_keys[] = trim($key);
				}
			}
			$this->metakey = implode(", ", $clean_keys); // put array back together delimited by ", "
		}

		return true;
	}

	/**
	 * Method to set the publishing state for a row or list of rows in the database
	 * table.  The method respects checked out rows by other users and will attempt
	 * to checkin rows that it can after adjustments are made.
	 *
	 * @param   mixed	An optional array of primary key values to update.  If not
	 *					set the instance property value is used.
	 * @param   integer The publishing state. eg. [0 = unpublished, 1 = published]
	 * @param   integer The user id of the user performing the operation.
	 * @return  boolean  True on success.
	 * @since   1.0.4
	 */
	// public function publish($pks = null, $state = 1, $userId = 0)
	// {
	// 	$k = $this->_tbl_key;

	// 	// Sanitize input.
	// 	JArrayHelper::toInteger($pks);
	// 	$userId = (int) $userId;
	// 	$state  = (int) $state;

	// 	// If there are no primary keys set check to see if the instance key is set.
	// 	if (empty($pks))
	// 	{
	// 		if ($this->$k)
	// 		{
	// 			$pks = array($this->$k);
	// 		}
	// 		// Nothing to set publishing state on, return false.
	// 		else {
	// 			$this->setError(JText::_('JLIB_DATABASE_ERROR_NO_ROWS_SELECTED'));
	// 			return false;
	// 		}
	// 	}

	// 	// Build the WHERE clause for the primary keys.
	// 	$where = $k.'='.implode(' OR '.$k.'=', $pks);

	// 	// Determine if there is checkin support for the table.
	// 	if (!property_exists($this, 'checked_out') || !property_exists($this, 'checked_out_time'))
	// 	{
	// 		$checkin = '';
	// 	}
	// 	else
	// 	{
	// 		$checkin = ' AND (checked_out = 0 OR checked_out = '.(int) $userId.')';
	// 	}

	// 	// Update the publishing state for rows with the given primary keys.
	// 	$this->_db->setQuery(
	// 		'UPDATE '.$this->_db->quoteName($this->_tbl) .
	// 		' SET '.$this->_db->quoteName('state').' = '.(int) $state .
	// 		' WHERE ('.$where.')' .
	// 		$checkin
	// 	);

	// 	try
	// 	{
	// 		$this->_db->execute();
	// 	}
	// 	catch (RuntimeException $e)
	// 	{
	// 		$this->setError($e->getMessage());
	// 		return false;
	// 	}

	// 	// If checkin is supported and all rows were adjusted, check them in.
	// 	if ($checkin && (count($pks) == $this->_db->getAffectedRows()))
	// 	{
	// 		// Checkin the rows.
	// 		foreach ($pks as $pk)
	// 		{
	// 			$this->checkin($pk);
	// 		}
	// 	}

	// 	// If the JTable instance value is in the list of primary keys that were set, set the instance.
	// 	if (in_array($this->$k, $pks))
	// 	{
	// 		$this->state = $state;
	// 	}

	// 	$this->setError('');
	// 	return true;
	// }
}
